@@ -54,7 +54,7 @@
 #
 # These variables control the setup
 #
-set addrVersion {$Revision: 1.13 $}
+set addrVersion {$Revision: 1.14 $}
 
 # Addr_debug, if ==1, enables printing messages while this stuff runs.
 # Set Addr_debug 1 in your user.tcl before invoking Addr_Init to enable debug messages
@@ -710,13 +710,11 @@ proc LDAP_Lookup {n} {
     #
     # ...
     set result {}
-    foreach i $ldap_results {
-        if [regexp -nocase {^mail=([^,]*)$} $i dummy email] {
+    foreach i [split $ldap_results \n ] {
+        if [regexp -nocase {^mail[=:] *([^,]*)$} $i dummy email] {
             lappend result "[LDAP_Entry_FormatForMail $email $name]"
-        } elseif [regexp -nocase "^cn=(.*)$" $i dummy tmp] {
+        } elseif [regexp -nocase {^cn[=:] *(.*)$} $i dummy tmp] {
             set name $tmp
-        } else {
-            append name " $i"
         }
     }
     
