@@ -11,7 +11,7 @@
 # any specification.
 
 proc FolderDialogInner {path label cancelProc okProc message} {
-    global mhProfile exwin exmh tk_version
+    global mhProfile exwin exmh
 
    set t $path
    if [Exwin_Toplevel $path $label FolderDialog nomenu] {
@@ -27,8 +27,8 @@ proc FolderDialogInner {path label cancelProc okProc message} {
 
 	set f [Widget_Frame $t but Rim]
 	$f configure -bd 10
-	Widget_AddBut $f cancel "Cancel" [list $cancelProc $path] left
-	Widget_AddBut $f ok "OK" [list $okProc $path $e] right
+       Widget_AddBut $f cancel "Cancel" [list $cancelProc $path] {left filly}
+       Widget_AddBut $f ok "OK" [list $okProc $path $e] {right filly}
     } else {
 	$t.msg config -text $message
 	set e $path.name.rim.name
@@ -85,6 +85,14 @@ proc FolderNewCommit { top entry } {
 	    Exwin_Dismiss $top
 	    return
 	}
+	if {[catch {
+	    close [open [file join $path .mh_sequences] w]
+	    if [info exists mhProfile(folder-protect)] {
+		exec chmod $mhProfile(folder-protect) $path/.mh_sequences
+	    }
+	} msg]} {
+	    Exmh_Debug ".mh_sequences: $msg"
+	}
 	if [info exists mhProfile(folder-protect)] {
 	    exec chmod $mhProfile(folder-protect) $path
 	}
